Background Information
======================

This section contains explanations and discussions to give background and
context to parts of CSET, such as why something is the way it is.

.. toctree::
    :maxdepth: 1

    why-cset
    why-workflow
